/*
 * Copyright 2010 Mihai Niculescu <q.quark@gmail.com>
 *
 * This file is part of EqualX Project (https://launchpad.net/equalx/)
 *
 * EqualX is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * EqualX is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <QGridLayout>
#include <QEvent>
#include <QTimer>

#include "WidgetFramePopup.h"

WidgetFramePopup::WidgetFramePopup(QWidget * parent)
        : QFrame(parent,  Qt::Popup)
{
    m_grid = new QGridLayout;
    m_grid->setContentsMargins(0 ,0, 0,0);
    m_grid->setSpacing(0);

    setFrameShadow(QFrame::Sunken);
    setFrameShape(QFrame::Box);

    setLayout(m_grid);

}

void WidgetFramePopup::addWidget(QWidget *widget, int i, int j)
{
    m_grid->addWidget(widget, i, j);

}

bool WidgetFramePopup::isEmpty()
{
    if(m_grid->count() > 0 )
        return false;
    else
        return true;
}

void WidgetFramePopup::popup()
{
    QWidget *parentWidget = (QWidget*)parent();

    if(parentWidget){
        QPoint p = parentWidget->mapToGlobal( QPoint(0,0));

        setGeometry(p.x(), p.y() + parentWidget->height(), parentWidget->width(), sizeHint().height() );
    }

    show();
}

void WidgetFramePopup::enterEvent(QEvent *event)
{

    if(isHidden() )
        show();

    QFrame::enterEvent(event);
}

void WidgetFramePopup::leaveEvent(QEvent *event)
{
    if( event->type() == QEvent::Leave ){
      // QTimer::singleShot(400, this, SLOT(hideMenu()) );

    }

    QFrame::leaveEvent(event);

}

void WidgetFramePopup::hideMenu()
{
    //keep it if mouse is over parent widget
    if(! ((QWidget*)parent())->underMouse() ){
        hide();
    }
}
